#!/usr/bin/perl -w
use strict;
use utf8;
use lib qw(lib);
use MySQL::Admin::GUI;
ContentHeader("cgi-bin//config/settings.pl");
print Body();